##############################################################################################
# bring in data from an outside tab delimited text file, can be converted from a EXCEL file
#     (shown in this example)
#
##############################################################################################

rm(list=ls(all=TRUE))  # remove any objects left from previous runs of R

plotdat<- read.table("E:\\R_workshop\\materials for nigeria_2009\\course_materials_nigera\\data\\crd.txt",header=TRUE)

attach(plotdat)
names(plotdat)
dim(plotdat)

tapply(AveDbh,Treatment,mean)

logAveDbh<-log(AveDbh)

##########################################################################
#  Box plots, one orginal and one log-transformed.  Set this up for two
#  plots on a page.  After, if you just highlight and run one boxplot,
# you will just get that plot.  
#########################################################################

par(mfrow=c(1,2))
boxplot(AveDbh~Treatment,data=plotdat,col='pink', main="Average Dbh by Treatment")
boxplot(logAveDbh~Treatment,data=plotdat,col='pink', main="Log AveDbh by Treatment")
par(mfrow=c(1,1))

##########################################################################
# ANOVA: Use lm to get the analysis of variance table -- and F test for treatments
# Check assumptions of equal variance across treatments, and normality
# of residuals.  Residual here is the observed value - mean for the 
# treatment.  
#########################################################################

model1<-lm(AveDbh~Treatment,data=plotdat)
anova(model1)

summary(model1)

yhat<-fitted(model1)
resid<-resid(model1)

par(mfrow=c(2,2))
plot(resid~yhat)  # residual plot
qqnorm(resid)     # normality plot
qqline(resid,col=2)
hist(resid, breaks =6 , density=10,col="green", border="black") # draws a histogramresid<-resid(lm.model1)
par(mfrow=c(1,1))

##########################################################################
# If treatment means vary, then test which pairs differ
#########################################################################

pairwise.t.test(AveDbh,Treatment,p.adj="bonferroni")

#############################################################################################
#  If assumptions were not met (the graphs show the residuals are not normally 
#  distributed, and/or the residual plot indicates the spread of residuals is
#  not all the same), then repeat the ANOVA using LogAveDbh instead.  
#############################################################################################


#############################################################################################
#  Clean up all of your files, or shut down R before doing another exercise
#############################################################################################














