##############################################################################################
# bring in data from an outside tab delimited text file, can be converted from a EXCEL file
#     (shown in this example)
#
##############################################################################################
standdat<- read.table("E:\\R_workshop\\materials for nigeria_2009\\course_materials_nigera\\data\\stand.txt",header=TRUE)

attach(standdat)
names(standdat)
standdat

ls()


#############################################################################################
#  Using step to do stepwise methods to help in choosing x variables.  Starts with all
#  x variables, as shown by volha ~ . and the specific data frame. First one uses
#  forward (in only), second one uses backward (out only), and last allows
#  variables to be dropped and later to enter back in (both).  
############################################################################################

summary(model1 <- lm(vol.ha ~ .,data = standdat))
step.model1 <- step(model1,direction=c("forward"))
summary(step.model1)

step.model2 <- step(model1,direction=c("backward"))
summary(step.model2)

step.model3 <- step(model1,direction=c("both"))
summary(step.model3)

#############################################################################################
#  Once you have a model, do a full analysis, as you need to check assumptions, etc.  
#############################################################################################

lm.volume<-lm(vol.ha~qdbh+topht)  
lm.volume
summary(lm.volume)
anova(lm.volume))

yhat<-fitted(lm.volume)
resid<-resid(lm.volume)
cbind(vol.ha,yhat,resid)  # list measured and predicted height and differences (i.e. residuals)

plot(yhat~vol.ha)
abline(a=0,b=1)   # plot a reference line where yhat equals volha

plot(resid~yhat)  # residual plot

plot(resid~qdbh)    #different residual plot

qqnorm(resid)     # normality plot
qqline(resid,col=2)

hist(resid, breaks =6 , density=10,col="green", border="black") # draws a histogram

# get 95% confidence intervals for the average vol per ha, given each of the observed x's in the data, using the equation
predCI<- predict(lm.volume, standdat,interval="confidence")
predCI

#############################################################################################
#  Clean up all of your files, or shut down R before doing another exercise
#############################################################################################













